@@ -1,11 +1,17 @@
 const assert = require('assert');
 const fs = require('fs');
-
-const mock = require('..');
+const mock = require('../lib/index.js');
 
 /**
  * Test setup.  Not timed.
  */
+exports.afterEach = function () {
+  mock.restore();
+};
+
+/**
+ * Test teardown.  Not timed.
+ */
 exports.beforeEach = function () {
   mock({
     'foo-mock.txt': 'foo',
@@ -14,7 +20,7 @@ exports.beforeEach = function () {
 
 /**
  * Timed test.
- * @param {function(Error)} done Callback.
+ * @param {function(Error):void} done Callback.
  */
 exports.test = function (done) {
   fs.readFile('foo-mock.txt', 'utf8', function (err, str) {
@@ -23,10 +29,3 @@ exports.test = function (done) {
     done();
   });
 };
-
-/**
- * Test teardown.  Not timed.
- */
-exports.afterEach = function () {
-  mock.restore();
-};
