@@ -1,13 +1,11 @@
-'use strict';
-
+const constants = require('constants');
 const path = require('path');
-const File = require('./file.js');
 const FileDescriptor = require('./descriptor.js');
 const Directory = require('./directory.js');
-const SymbolicLink = require('./symlink.js');
 const {FSError} = require('./error.js');
-const constants = require('constants');
-const getPathParts = require('./filesystem.js').getPathParts;
+const File = require('./file.js');
+const {getPathParts, getRealPath} = require('./filesystem.js');
+const SymbolicLink = require('./symlink.js');
 
 const MODE_TO_KTYPE = {
   [constants.S_IFREG]: constants.UV_DIRENT_FILE,
@@ -34,17 +32,17 @@ const MAX_LINKS = 50;
 /**
  * Call the provided function and either return the result or call the callback
  * with it (depending on if a callback is provided).
- * @param {function()} callback Optional callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
- * @param {object} thisArg This argument for the following function.
- * @param {function()} func Function to call.
+ * @param {function():void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {Object} thisArg This argument for the following function.
+ * @param {function():any} func Function to call.
  * @return {*} Return (if callback is not provided).
  */
 function maybeCallback(callback, ctx, thisArg, func) {
   let err = null;
   let val;
 
-  if (kUsePromises && callback === kUsePromises) {
+  if (usePromises(callback)) {
     // support nodejs v10+ fs.promises
     try {
       val = func.call(thisArg);
@@ -52,7 +50,7 @@ function maybeCallback(callback, ctx, thisArg, func) {
       err = e;
     }
     return new Promise(function (resolve, reject) {
-      process.nextTick(function () {
+      setImmediate(function () {
         if (err) {
           reject(err);
         } else {
@@ -66,7 +64,7 @@ function maybeCallback(callback, ctx, thisArg, func) {
     } catch (e) {
       err = e;
     }
-    process.nextTick(function () {
+    setImmediate(function () {
       if (val === undefined) {
         callback(err);
       } else {
@@ -86,9 +84,13 @@ function maybeCallback(callback, ctx, thisArg, func) {
   }
 }
 
+function usePromises(callback) {
+  return kUsePromises && callback === kUsePromises;
+}
+
 /**
  * set syscall property on context object, only for nodejs v10+.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @param {string} syscall Name of syscall.
  */
 function markSyscall(ctx, syscall) {
@@ -220,7 +222,7 @@ Binding.prototype.untrackDescriptorById = function (fd) {
  * @param {string|Buffer} filepath The file path.
  * @param {string} encoding The encoding for the return.
  * @param {Function} callback The callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {string|Buffer} The real path.
  */
 Binding.prototype.realpath = function (filepath, encoding, callback, ctx) {
@@ -260,10 +262,8 @@ Binding.prototype.realpath = function (filepath, encoding, callback, ctx) {
       throw new FSError('ENOENT', filepath);
     }
 
-    if (process.platform === 'win32' && realPath.startsWith('\\\\?\\')) {
-      // Remove win32 file namespace prefix \\?\
-      realPath = realPath.slice(4);
-    }
+    // Remove win32 file namespace prefix \\?\
+    realPath = getRealPath(realPath);
 
     if (encoding === 'buffer') {
       realPath = Buffer.from(realPath);
@@ -284,8 +284,8 @@ function fillStats(stats, bigint) {
  * Stat an item.
  * @param {string} filepath Path.
  * @param {boolean} bigint Use BigInt.
- * @param {function(Error, Float64Array|BigUint64Array)} callback Callback (optional).
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error, Float64Array|BigUint64Array):void} callback Callback (optional).
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {Float64Array|BigUint64Array|undefined} Stats or undefined (if sync).
  */
 Binding.prototype.stat = function (filepath, bigint, callback, ctx) {
@@ -296,7 +296,7 @@ Binding.prototype.stat = function (filepath, bigint, callback, ctx) {
     let item = this._system.getItem(filepath);
     if (item instanceof SymbolicLink) {
       item = this._system.getItem(
-        path.resolve(path.dirname(filepath), item.getPath())
+        path.resolve(path.dirname(filepath), item.getPath()),
       );
     }
     if (!item) {
@@ -308,12 +308,23 @@ Binding.prototype.stat = function (filepath, bigint, callback, ctx) {
   });
 };
 
+/**
+ * Stat an item.
+ * @param {string} filepath Path.
+ * @param {boolean} bigint Use BigInt.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @return {Float64Array|BigUint64Array|undefined} Stats or undefined if sync.
+ */
+Binding.prototype.statSync = function (filepath, bigint, ctx) {
+  return this.stat(filepath, bigint, undefined, ctx);
+};
+
 /**
  * Stat an item.
  * @param {number} fd File descriptor.
  * @param {boolean} bigint Use BigInt.
- * @param {function(Error, Float64Array|BigUint64Array)} callback Callback (optional).
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error, Float64Array|BigUint64Array):void} callback Callback (optional).
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {Float64Array|BigUint64Array|undefined} Stats or undefined (if sync).
  */
 Binding.prototype.fstat = function (fd, bigint, callback, ctx) {
@@ -331,8 +342,8 @@ Binding.prototype.fstat = function (fd, bigint, callback, ctx) {
 /**
  * Close a file descriptor.
  * @param {number} fd File descriptor.
- * @param {function(Error)} callback Callback (optional).
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error):void} callback Callback (optional).
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {*} The return if no callback.
  */
 Binding.prototype.close = function (fd, callback, ctx) {
@@ -343,13 +354,23 @@ Binding.prototype.close = function (fd, callback, ctx) {
   });
 };
 
+/**
+ * Close a file descriptor.
+ * @param {number} fd File descriptor.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return.
+ */
+Binding.prototype.closeSync = function (fd, ctx) {
+  return this.close(fd, undefined, ctx);
+};
+
 /**
  * Open and possibly create a file.
  * @param {string} pathname File path.
  * @param {number} flags Flags.
  * @param {number} mode Mode.
- * @param {function(Error, string)} callback Callback (optional).
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error, string):void} callback Callback (optional).
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {string} File descriptor (if sync).
  */
 Binding.prototype.open = function (pathname, flags, mode, callback, ctx) {
@@ -357,11 +378,11 @@ Binding.prototype.open = function (pathname, flags, mode, callback, ctx) {
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     pathname = deBuffer(pathname);
-    const descriptor = new FileDescriptor(flags);
+    const descriptor = new FileDescriptor(flags, usePromises(callback));
     let item = this._system.getItem(pathname);
     while (item instanceof SymbolicLink) {
       item = this._system.getItem(
-        path.resolve(path.dirname(pathname), item.getPath())
+        path.resolve(path.dirname(pathname), item.getPath()),
       );
     }
     if (descriptor.isExclusive() && item) {
@@ -412,6 +433,18 @@ Binding.prototype.open = function (pathname, flags, mode, callback, ctx) {
   });
 };
 
+/**
+ * Open and possibly create a file.
+ * @param {string} pathname File path.
+ * @param {number} flags Flags.
+ * @param {number} mode Mode.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @return {string} File descriptor.
+ */
+Binding.prototype.openSync = function (pathname, flags, mode, ctx) {
+  return this.open(pathname, flags, mode, undefined, ctx);
+};
+
 /**
  * Open a file handler. A new api in nodejs v10+ for fs.promises
  * @param {string} pathname File path.
@@ -443,9 +476,9 @@ Binding.prototype.openFileHandle = function (pathname, flags, mode, callback) {
  * @param {number} length Number of bytes to read.
  * @param {?number} position Where to begin reading in the file.  If null,
  *     data will be read from the current file position.
- * @param {function(Error, number, Buffer)} callback Callback (optional) called
+ * @param {function(Error, number, Buffer):void} callback Callback (optional) called
  *     with any error, number of bytes read, and the buffer.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {number} Number of bytes read (if sync).
  */
 Binding.prototype.read = function (
@@ -455,7 +488,7 @@ Binding.prototype.read = function (
   length,
   position,
   callback,
-  ctx
+  ctx,
 ) {
   markSyscall(ctx, 'read');
 
@@ -489,9 +522,9 @@ Binding.prototype.read = function (
  * @param {string} src Source file.
  * @param {string} dest Destination file.
  * @param {number} flags Modifiers for copy operation.
- * @param {function(Error)} callback Callback (optional) called
+ * @param {function(Error):void} callback Callback (optional) called
  *     with any error.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {*} The return if no callback is provided.
  */
 Binding.prototype.copyFile = function (src, dest, flags, callback, ctx) {
@@ -533,15 +566,27 @@ Binding.prototype.copyFile = function (src, dest, flags, callback, ctx) {
   });
 };
 
+/**
+ * Write to a file descriptor given a buffer.
+ * @param {string} src Source file.
+ * @param {string} dest Destination file.
+ * @param {number} flags Modifiers for copy operation.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
+ */
+Binding.prototype.copyFileSync = function (src, dest, flags, ctx) {
+  return this.copyFile(src, dest, flags, undefined, ctx);
+};
+
 /**
  * Write to a file descriptor given a buffer.
  * @param {string} fd File descriptor.
  * @param {Array<Buffer>} buffers Array of buffers with contents to write.
  * @param {?number} position Where to begin writing in the file.  If null,
  *     data will be written to the current file position.
- * @param {function(Error, number, Buffer)} callback Callback (optional) called
+ * @param {function(Error, number, Buffer):void} callback Callback (optional) called
  *     with any error, number of bytes written, and the buffer.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {number} Number of bytes written (if sync).
  */
 Binding.prototype.writeBuffers = function (
@@ -549,7 +594,7 @@ Binding.prototype.writeBuffers = function (
   buffers,
   position,
   callback,
-  ctx
+  ctx,
 ) {
   markSyscall(ctx, 'write');
 
@@ -589,9 +634,9 @@ Binding.prototype.writeBuffers = function (
  * @param {number} length Number of bytes to write.
  * @param {?number} position Where to begin writing in the file.  If null,
  *     data will be written to the current file position.
- * @param {function(Error, number, Buffer)} callback Callback (optional) called
+ * @param {function(Error, number, Buffer):void} callback Callback (optional) called
  *     with any error, number of bytes written, and the buffer.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {number} Number of bytes written (if sync).
  */
 Binding.prototype.writeBuffer = function (
@@ -601,7 +646,7 @@ Binding.prototype.writeBuffer = function (
   length,
   position,
   callback,
-  ctx
+  ctx,
 ) {
   markSyscall(ctx, 'write');
 
@@ -630,11 +675,16 @@ Binding.prototype.writeBuffer = function (
       content,
       position,
       offset,
-      sourceEnd
+      sourceEnd,
     );
     file.setContent(content);
     descriptor.setPosition(newLength);
-    return written;
+    // If we're in fs.promises / FileHandle we need to return a promise
+    // Both fs.promises.open().then(fd => fs.write())
+    // and fs.openSync().writeSync() use this function
+    // without a callback, so we have to check if  the descriptor was opened
+    // with kUsePromises
+    return descriptor.isPromise() ? Promise.resolve(written) : written;
   });
 };
 
@@ -645,9 +695,9 @@ Binding.prototype.writeBuffer = function (
  * @param {number} position Where to begin writing in the file.  If null,
  *     data will be written to the current file position.
  * @param {string} encoding String encoding.
- * @param {function(Error, number, string)} callback Callback (optional) called
+ * @param {function(Error, number, string):void} callback Callback (optional) called
  *     with any error, number of bytes written, and the string.
- * @param {object} ctx The context.
+ * @param {Object} ctx The context.
  * @return {number} Number of bytes written (if sync).
  */
 Binding.prototype.writeString = function (
@@ -656,7 +706,7 @@ Binding.prototype.writeString = function (
   position,
   encoding,
   callback,
-  ctx
+  ctx,
 ) {
   markSyscall(ctx, 'write');
 
@@ -670,15 +720,15 @@ Binding.prototype.writeString = function (
       callback(err, written, returned && string);
     };
   }
-  return this.writeBuffer(fd, buffer, 0, string.length, position, wrapper, ctx);
+  return this.writeBuffer(fd, buffer, 0, buffer.length, position, wrapper, ctx);
 };
 
 /**
  * Rename a file.
  * @param {string} oldPath Old pathname.
  * @param {string} newPath New pathname.
- * @param {function(Error)} callback Callback (optional).
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error):void} callback Callback (optional).
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {undefined}
  */
 Binding.prototype.rename = function (oldPath, newPath, callback, ctx) {
@@ -724,14 +774,25 @@ Binding.prototype.rename = function (oldPath, newPath, callback, ctx) {
   });
 };
 
+/**
+ * Rename a file.
+ * @param {string} oldPath Old pathname.
+ * @param {string} newPath New pathname.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @return {undefined}
+ */
+Binding.prototype.renameSync = function (oldPath, newPath, ctx) {
+  return this.rename(oldPath, newPath, undefined, ctx);
+};
+
 /**
  * Read a directory.
  * @param {string} dirpath Path to directory.
  * @param {string} encoding The encoding ('utf-8' or 'buffer').
  * @param {boolean} withFileTypes whether or not to return fs.Dirent objects
- * @param {function(Error, (Array.<string>|Array.<Buffer>)} callback Callback
+ * @param {function(Error, (Array<string> | Array<Buffer>)): void} callback Callback
  *     (optional) called with any error or array of items in the directory.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {Array<string> | Array<Buffer>} Array of items in directory (if sync).
  */
 Binding.prototype.readdir = function (
@@ -739,7 +800,7 @@ Binding.prototype.readdir = function (
   encoding,
   withFileTypes,
   callback,
-  ctx
+  ctx,
 ) {
   markSyscall(ctx, 'scandir');
 
@@ -781,13 +842,50 @@ Binding.prototype.readdir = function (
   });
 };
 
+/**
+ * Read file as utf8 string.
+ * @param {string} name file to write.
+ * @param {number} flags Flags.
+ * @return {string} the file content.
+ */
+Binding.prototype.readFileUtf8 = function (name, flags) {
+  const fd = this.open(name, flags);
+  const descriptor = this.getDescriptorById(fd);
+
+  if (!descriptor.isRead()) {
+    throw new FSError('EBADF');
+  }
+  const file = descriptor.getItem();
+  if (file instanceof Directory) {
+    throw new FSError('EISDIR');
+  }
+  if (!(file instanceof File)) {
+    // deleted or not a regular file
+    throw new FSError('EBADF');
+  }
+  const content = file.getContent();
+  return content.toString('utf8');
+};
+
+/**
+ * Write a utf8 string.
+ * @param {string} filepath file to write.
+ * @param {string} data data to write to filepath.
+ * @param {number} flags Flags.
+ * @param {number} mode Mode.
+ */
+Binding.prototype.writeFileUtf8 = function (filepath, data, flags, mode) {
+  const destFd = this.open(filepath, flags, mode);
+  this.writeString(destFd, data, null, 'utf8');
+};
+
 /**
  * Create a directory.
  * @param {string} pathname Path to new directory.
  * @param {number} mode Permissions.
  * @param {boolean} recursive Recursively create deep directory. (added in nodejs v10+)
- * @param {function(Error)} callback Optional callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error):void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {*} The return if no callback is provided.
  */
 Binding.prototype.mkdir = function (pathname, mode, recursive, callback, ctx) {
@@ -828,8 +926,8 @@ Binding.prototype.mkdir = function (pathname, mode, recursive, callback, ctx) {
 /**
  * Remove a directory.
  * @param {string} pathname Path to directory.
- * @param {function(Error)} callback Optional callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error):void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {*} The return if no callback is provided.
  */
 Binding.prototype.rmdir = function (pathname, callback, ctx) {
@@ -863,8 +961,8 @@ const MAX_ATTEMPTS = 62 * 62 * 62;
  * See http://web.mit.edu/freebsd/head/lib/libc/stdio/mktemp.c
  * @param {string} prefix Path template (trailing Xs will be replaced).
  * @param {string} encoding The encoding ('utf-8' or 'buffer').
- * @param {function(Error, string)} callback Optional callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error, string):void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {*} The return if no callback is provided.
  */
 Binding.prototype.mkdtemp = function (prefix, encoding, callback, ctx) {
@@ -895,7 +993,7 @@ Binding.prototype.mkdtemp = function (prefix, encoding, callback, ctx) {
       let replacement = '';
       while (template.charAt(position) === 'X') {
         replacement += PATH_CHARS.charAt(
-          Math.floor(PATH_CHARS.length * Math.random())
+          Math.floor(PATH_CHARS.length * Math.random()),
         );
         position -= 1;
       }
@@ -923,8 +1021,8 @@ Binding.prototype.mkdtemp = function (prefix, encoding, callback, ctx) {
  * Truncate a file.
  * @param {number} fd File descriptor.
  * @param {number} len Number of bytes.
- * @param {function(Error)} callback Optional callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error):void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {*} The return if no callback is provided.
  */
 Binding.prototype.ftruncate = function (fd, len, callback, ctx) {
@@ -950,8 +1048,8 @@ Binding.prototype.ftruncate = function (fd, len, callback, ctx) {
  * Legacy support.
  * @param {number} fd File descriptor.
  * @param {number} len Number of bytes.
- * @param {function(Error)} callback Optional callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error):void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  */
 Binding.prototype.truncate = Binding.prototype.ftruncate;
 
@@ -960,8 +1058,8 @@ Binding.prototype.truncate = Binding.prototype.ftruncate;
  * @param {string} pathname Path.
  * @param {number} uid User id.
  * @param {number} gid Group id.
- * @param {function(Error)} callback Optional callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error):void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {*} The return if no callback is provided.
  */
 Binding.prototype.chown = function (pathname, uid, gid, callback, ctx) {
@@ -983,8 +1081,8 @@ Binding.prototype.chown = function (pathname, uid, gid, callback, ctx) {
  * @param {number} fd File descriptor.
  * @param {number} uid User id.
  * @param {number} gid Group id.
- * @param {function(Error)} callback Optional callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error):void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {*} The return if no callback is provided.
  */
 Binding.prototype.fchown = function (fd, uid, gid, callback, ctx) {
@@ -1002,8 +1100,8 @@ Binding.prototype.fchown = function (fd, uid, gid, callback, ctx) {
  * Change permissions.
  * @param {string} pathname Path.
  * @param {number} mode Mode.
- * @param {function(Error)} callback Optional callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error):void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {*} The return if no callback is provided.
  */
 Binding.prototype.chmod = function (pathname, mode, callback, ctx) {
@@ -1023,8 +1121,8 @@ Binding.prototype.chmod = function (pathname, mode, callback, ctx) {
  * Change permissions.
  * @param {number} fd File descriptor.
  * @param {number} mode Mode.
- * @param {function(Error)} callback Optional callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error):void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {*} The return if no callback is provided.
  */
 Binding.prototype.fchmod = function (fd, mode, callback, ctx) {
@@ -1040,8 +1138,8 @@ Binding.prototype.fchmod = function (fd, mode, callback, ctx) {
 /**
  * Delete a named item.
  * @param {string} pathname Path to item.
- * @param {function(Error)} callback Optional callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error):void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {*} The return if no callback is provided.
  */
 Binding.prototype.unlink = function (pathname, callback, ctx) {
@@ -1061,21 +1159,40 @@ Binding.prototype.unlink = function (pathname, callback, ctx) {
   });
 };
 
+/**
+ * Delete a named item.
+ * @param {string} pathname Path to item.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
+ */
+Binding.prototype.unlinkSync = function (pathname, ctx) {
+  return this.unlink(pathname, undefined, ctx);
+};
+
 /**
  * Update timestamps.
  * @param {string} pathname Path to item.
  * @param {number} atime Access time (in seconds).
  * @param {number} mtime Modification time (in seconds).
- * @param {function(Error)} callback Optional callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error):void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {*} The return if no callback is provided.
  */
 Binding.prototype.utimes = function (pathname, atime, mtime, callback, ctx) {
   markSyscall(ctx, 'utimes');
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function () {
-    pathname = deBuffer(pathname);
-    const item = this._system.getItem(pathname);
+    let filepath = deBuffer(pathname);
+    let item = this._system.getItem(filepath);
+    let links = 0;
+    while (item instanceof SymbolicLink) {
+      if (links > MAX_LINKS) {
+        throw new FSError('ELOOP', filepath);
+      }
+      filepath = path.resolve(path.dirname(filepath), item.getPath());
+      item = this._system.getItem(filepath);
+      ++links;
+    }
     if (!item) {
       throw new FSError('ENOENT', pathname);
     }
@@ -1084,13 +1201,37 @@ Binding.prototype.utimes = function (pathname, atime, mtime, callback, ctx) {
   });
 };
 
+/**
+ * Update timestamps.
+ * @param {string} pathname Path to item.
+ * @param {number} atime Access time (in seconds).
+ * @param {number} mtime Modification time (in seconds).
+ * @param {function(Error):void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
+ */
+Binding.prototype.lutimes = function (pathname, atime, mtime, callback, ctx) {
+  markSyscall(ctx, 'utimes');
+
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
+    pathname = deBuffer(pathname);
+    const item = this._system.getItem(pathname);
+    if (!item) {
+      throw new FSError('ENOENT', pathname);
+    }
+    // lutimes doesn't follow symlink
+    item.setATime(new Date(atime * 1000));
+    item.setMTime(new Date(mtime * 1000));
+  });
+};
+
 /**
  * Update timestamps.
  * @param {number} fd File descriptor.
  * @param {number} atime Access time (in seconds).
  * @param {number} mtime Modification time (in seconds).
- * @param {function(Error)} callback Optional callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error):void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {*} The return if no callback is provided.
  */
 Binding.prototype.futimes = function (fd, atime, mtime, callback, ctx) {
@@ -1098,7 +1239,17 @@ Binding.prototype.futimes = function (fd, atime, mtime, callback, ctx) {
 
   return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     const descriptor = this.getDescriptorById(fd);
-    const item = descriptor.getItem();
+    let item = descriptor.getItem();
+    let filepath = this._system.getFilepath(item);
+    let links = 0;
+    while (item instanceof SymbolicLink) {
+      if (links > MAX_LINKS) {
+        throw new FSError('ELOOP', filepath);
+      }
+      filepath = path.resolve(path.dirname(filepath), item.getPath());
+      item = this._system.getItem(filepath);
+      ++links;
+    }
     item.setATime(new Date(atime * 1000));
     item.setMTime(new Date(mtime * 1000));
   });
@@ -1107,8 +1258,8 @@ Binding.prototype.futimes = function (fd, atime, mtime, callback, ctx) {
 /**
  * Synchronize in-core state with storage device.
  * @param {number} fd File descriptor.
- * @param {function(Error)} callback Optional callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error):void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {*} The return if no callback is provided.
  */
 Binding.prototype.fsync = function (fd, callback, ctx) {
@@ -1122,8 +1273,8 @@ Binding.prototype.fsync = function (fd, callback, ctx) {
 /**
  * Synchronize in-core metadata state with storage device.
  * @param {number} fd File descriptor.
- * @param {function(Error)} callback Optional callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error):void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {*} The return if no callback is provided.
  */
 Binding.prototype.fdatasync = function (fd, callback, ctx) {
@@ -1138,8 +1289,8 @@ Binding.prototype.fdatasync = function (fd, callback, ctx) {
  * Create a hard link.
  * @param {string} srcPath The existing file.
  * @param {string} destPath The new link to create.
- * @param {function(Error)} callback Optional callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error):void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {*} The return if no callback is provided.
  */
 Binding.prototype.link = function (srcPath, destPath, callback, ctx) {
@@ -1174,8 +1325,8 @@ Binding.prototype.link = function (srcPath, destPath, callback, ctx) {
  * @param {string} srcPath Path from link to the source file.
  * @param {string} destPath Path for the generated link.
  * @param {string} type Ignored (used for Windows only).
- * @param {function(Error)} callback Optional callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error):void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {*} The return if no callback is provided.
  */
 Binding.prototype.symlink = function (srcPath, destPath, type, callback, ctx) {
@@ -1200,12 +1351,24 @@ Binding.prototype.symlink = function (srcPath, destPath, type, callback, ctx) {
   });
 };
 
+/**
+ * Create a symbolic link.
+ * @param {string} srcPath Path from link to the source file.
+ * @param {string} destPath Path for the generated link.
+ * @param {string} type Ignored (used for Windows only).
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
+ */
+Binding.prototype.symlinkSync = function (srcPath, destPath, type, ctx) {
+  return this.symlink(srcPath, destPath, type, undefined, ctx);
+};
+
 /**
  * Read the contents of a symbolic link.
  * @param {string} pathname Path to symbolic link.
  * @param {string} encoding The encoding ('utf-8' or 'buffer').
- * @param {function(Error, (string|Buffer))} callback Optional callback.
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error, (string|Buffer)):void} callback Optional callback.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {string|Buffer} Symbolic link contents (path to source).
  */
 Binding.prototype.readlink = function (pathname, encoding, callback, ctx) {
@@ -1238,8 +1401,8 @@ Binding.prototype.readlink = function (pathname, encoding, callback, ctx) {
  * Stat an item.
  * @param {string} filepath Path.
  * @param {boolean} bigint Use BigInt.
- * @param {function(Error, Float64Array|BigUint64Array)} callback Callback (optional).
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error, Float64Array|BigUint64Array):void} callback Callback (optional).
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {Float64Array|BigUint64Array|undefined} Stats or undefined (if sync).
  */
 Binding.prototype.lstat = function (filepath, bigint, callback, ctx) {
@@ -1261,8 +1424,8 @@ Binding.prototype.lstat = function (filepath, bigint, callback, ctx) {
  * Tests user permissions.
  * @param {string} filepath Path.
  * @param {number} mode Mode.
- * @param {function(Error)} callback Callback (optional).
- * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {function(Error):void} callback Callback (optional).
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
  * @return {*} The return if no callback is provided.
  */
 Binding.prototype.access = function (filepath, mode, callback, ctx) {
@@ -1284,32 +1447,81 @@ Binding.prototype.access = function (filepath, mode, callback, ctx) {
       throw new FSError('ENOENT', filepath);
     }
     if (mode && process.getuid && process.getgid) {
-      const itemMode = item.getMode();
-      if (item.getUid() === process.getuid()) {
-        if ((itemMode & (mode * 64)) !== mode * 64) {
-          throw new FSError('EACCES', filepath);
-        }
-      } else if (item.getGid() === process.getgid()) {
-        if ((itemMode & (mode * 8)) !== mode * 8) {
-          throw new FSError('EACCES', filepath);
-        }
-      } else {
-        if ((itemMode & mode) !== mode) {
-          throw new FSError('EACCES', filepath);
-        }
+      if (mode & constants.R_OK && !item.canRead()) {
+        throw new FSError('EACCES', filepath);
+      }
+      if (mode & constants.W_OK && !item.canWrite()) {
+        throw new FSError('EACCES', filepath);
+      }
+      if (mode & constants.X_OK && !item.canExecute()) {
+        throw new FSError('EACCES', filepath);
       }
     }
   });
 };
 
+/**
+ * Tests user permissions.
+ * @param {string} filepath Path.
+ * @param {number} mode Mode.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
+ */
+Binding.prototype.accessSync = function (filepath, mode, ctx) {
+  return this.access(filepath, mode, undefined, ctx);
+};
+
+/**
+ * Tests whether or not the given path exists.
+ * @param {string} filepath Path.
+ * @param {function(Error):void} callback Callback (optional).
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
+ */
+Binding.prototype.exists = function (filepath, callback, ctx) {
+  markSyscall(ctx, 'exists');
+
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
+    filepath = deBuffer(filepath);
+    let item;
+    try {
+      item = this._system.getItem(filepath);
+    } catch {
+      // ignore errors
+      // see https://github.com/nodejs/node/blob/v22.11.0/lib/fs.js#L255-L257
+      return false;
+    }
+
+    if (item) {
+      if (item instanceof SymbolicLink) {
+        return this.exists(
+          path.resolve(path.dirname(filepath), item.getPath()),
+          callback,
+          ctx,
+        );
+      }
+      return true;
+    }
+    return false;
+  });
+};
+
+/**
+ * Tests whether or not the given path exists.
+ * @param {string} filepath Path.
+ * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
+ */
+Binding.prototype.existsSync = function (filepath, ctx) {
+  return this.exists(filepath, undefined, ctx);
+};
+
 /**
  * Not yet implemented.
- * @type {function()}
  */
 Binding.prototype.StatWatcher = notImplemented;
 
 /**
  * Export the binding constructor.
- * @type {function()}
  */
 module.exports = Binding;
