@@ -1,8 +1,6 @@
-'use strict';
-
+const constants = require('constants');
 const util = require('util');
 const Item = require('./item.js');
-const constants = require('constants');
 
 /**
  * A directory.
@@ -92,7 +90,7 @@ Directory.prototype.list = function () {
 /**
  * Get directory stats.
  * @param {bolean} bigint Use BigInt.
- * @return {object} Stats properties.
+ * @return {Object} Stats properties.
  */
 Directory.prototype.getStats = function (bigint) {
   const stats = Item.prototype.getStats.call(this, bigint);
@@ -107,6 +105,5 @@ Directory.prototype.getStats = function (bigint) {
 
 /**
  * Export the constructor.
- * @type {function()}
  */
 module.exports = Directory;
