@@ -1,8 +1,6 @@
-'use strict';
-
+const constants = require('constants');
 const util = require('util');
 const Item = require('./item.js');
-const constants = require('constants');
 
 const EMPTY = Buffer.alloc(0);
 
@@ -49,7 +47,7 @@ File.prototype.setContent = function (content) {
 /**
  * Get file stats.
  * @param {boolean} bigint Use BigInt.
- * @return {object} Stats properties.
+ * @return {Object} Stats properties.
  */
 File.prototype.getStats = function (bigint) {
   const size = this._content.length;
@@ -65,7 +63,6 @@ File.prototype.getStats = function (bigint) {
 
 /**
  * Export the constructor.
- * @type {function()}
  */
 module.exports = File;
 exports = module.exports;
@@ -80,6 +77,7 @@ function StandardInput() {
 }
 util.inherits(StandardInput, File);
 
+exports.StandardError = StandardError;
 exports.StandardInput = StandardInput;
 
 /**
@@ -123,5 +121,3 @@ StandardError.prototype.setContent = function (content) {
     process.stderr.write(content);
   }
 };
-
-exports.StandardError = StandardError;
