@@ -1,5 +1,3 @@
-'use strict';
-
 const fsBinding = process.binding('fs');
 const statsConstructor = fsBinding.statValues
   ? fsBinding.statValues.constructor
@@ -290,7 +288,7 @@ Item.prototype.setGid = function (gid) {
 /**
  * Get item stats.
  * @param {boolean} bigint Use BigInt.
- * @return {object} Stats properties.
+ * @return {Object} Stats properties.
  */
 Item.prototype.getStats = function (bigint) {
   const stats = bigint
@@ -333,6 +331,5 @@ Item.prototype.toString = function () {
 
 /**
  * Export the constructor.
- * @type {function()}
  */
 module.exports = Item;
