@@ -1,12 +1,10 @@
-'use strict';
-
 const {AbortError} = require('./error.js');
 const {FSReqCallback} = process.binding('fs');
 
 /**
  * This is a workaround for getting access to the ReadFileContext
  * prototype, which we need to be able to patch its methods.
- * @return {object} The prototype.
+ * @return {Object} The prototype.
  */
 exports.getReadFileContextPrototype = function () {
   const fs = require('fs');
@@ -36,8 +34,7 @@ exports.getReadFileContextPrototype = function () {
  * closes directly over the internal fs bindings, and is also eagerly loader.
  *
  * See https://github.com/tschaub/mock-fs/issues/332 for more information.
- *
- * @param {object} prototype The ReadFileContext prototype object to patch.
+ * @param {Object} prototype The ReadFileContext prototype object to patch.
  */
 exports.patchReadFileContext = function (prototype) {
   const origRead = prototype.read;
