@@ -1,8 +1,6 @@
-'use strict';
-
+const constants = require('constants');
 const util = require('util');
 const Item = require('./item.js');
-const constants = require('constants');
 
 /**
  * A directory.
@@ -38,7 +36,7 @@ SymbolicLink.prototype.getPath = function () {
 /**
  * Get symbolic link stats.
  * @param {boolean} bigint Use BigInt.
- * @return {object} Stats properties.
+ * @return {Object} Stats properties.
  */
 SymbolicLink.prototype.getStats = function (bigint) {
   const size = this._path.length;
@@ -54,6 +52,5 @@ SymbolicLink.prototype.getStats = function (bigint) {
 
 /**
  * Export the constructor.
- * @type {function()}
  */
 module.exports = SymbolicLink;
