@@ -1,7 +1,6 @@
-'use strict';
-
 const os = require('os');
 const path = require('path');
+const {describe, it} = require('mocha');
 const Directory = require('../../lib/directory.js');
 const File = require('../../lib/file.js');
 const FileSystem = require('../../lib/filesystem.js');
@@ -40,7 +39,7 @@ describe('FileSystem', function () {
     });
   });
 
-  describe('#getItem()', function () {
+  describe('#getItem() #getFilepath()', function () {
     it('gets an item', function () {
       const system = FileSystem.create({
         'one/two/three.js': 'contents',
@@ -49,6 +48,7 @@ describe('FileSystem', function () {
       const filepath = path.join('one', 'two', 'three.js');
       const item = system.getItem(filepath);
       assert.instanceOf(item, File);
+      assert.equal(system.getFilepath(item), path.resolve(filepath));
     });
 
     it('returns null if not found', function () {
@@ -79,10 +79,18 @@ describe('FileSystem', function () {
       });
       const file = system.getItem(path.join('dir-link', 'a'));
       assert.instanceOf(file, File);
+      assert.equal(
+        system.getFilepath(file),
+        path.resolve(path.join('b', 'c', 'dir', 'a')),
+      );
 
       const dir = system.getItem(path.join('dir-link', 'b'));
       assert.instanceOf(dir, Directory);
       assert.deepEqual(dir.list().sort(), ['c', 'd']);
+      assert.equal(
+        system.getFilepath(dir),
+        path.resolve(path.join('b', 'c', 'dir', 'b')),
+      );
     });
   });
 });
