@@ -1,8 +1,7 @@
-'use strict';
-
-const helper = require('../helper.js');
 const fs = require('fs');
+const {afterEach, beforeEach, describe, it} = require('mocha');
 const mock = require('../../lib/index.js');
+const helper = require('../helper.js');
 
 const assert = helper.assert;
 
@@ -103,7 +102,7 @@ if (process.getuid && process.getgid) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EACCES');
           done();
-        }
+        },
       );
     });
 
@@ -124,7 +123,7 @@ if (process.getuid && process.getgid) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EACCES');
           done();
-        }
+        },
       );
     });
 
@@ -145,7 +144,7 @@ if (process.getuid && process.getgid) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EACCES');
           done();
-        }
+        },
       );
     });
 
@@ -190,7 +189,7 @@ if (process.getuid && process.getgid) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EACCES');
           done();
-        }
+        },
       );
     });
 
@@ -211,7 +210,7 @@ if (process.getuid && process.getgid) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EACCES');
           done();
-        }
+        },
       );
     });
 
@@ -256,7 +255,7 @@ if (process.getuid && process.getgid) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EACCES');
           done();
-        }
+        },
       );
     });
 
@@ -277,7 +276,7 @@ if (process.getuid && process.getgid) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EACCES');
           done();
-        }
+        },
       );
     });
 
@@ -338,7 +337,7 @@ if (process.getuid && process.getgid) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EACCES');
           done();
-        }
+        },
       );
     });
 
@@ -383,7 +382,7 @@ if (process.getuid && process.getgid) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EACCES');
           done();
-        }
+        },
       );
     });
 
@@ -404,7 +403,7 @@ if (process.getuid && process.getgid) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EACCES');
           done();
-        }
+        },
       );
     });
 
@@ -465,7 +464,7 @@ if (process.getuid && process.getgid) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EACCES');
           done();
-        }
+        },
       );
     });
 
@@ -526,7 +525,7 @@ if (process.getuid && process.getgid) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EACCES');
           done();
-        }
+        },
       );
     });
 
@@ -621,7 +620,7 @@ if (process.getuid && process.getgid) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EACCES');
           done();
-        }
+        },
       );
     });
   });
