@@ -1,8 +1,7 @@
-'use strict';
-
-const helper = require('../helper.js');
 const fs = require('fs');
+const {afterEach, beforeEach, describe, it} = require('mocha');
 const mock = require('../../lib/index.js');
+const helper = require('../helper.js');
 
 const assert = helper.assert;
 
@@ -37,11 +36,14 @@ describe('fs.chmod(path, mode, callback)', function () {
   });
 
   it('promise changes permissions of a file', function (done) {
-    fs.promises.chmod('file.txt', parseInt('0664', 8)).then(function () {
-      const stats = fs.statSync('file.txt');
-      assert.equal(stats.mode & parseInt('0777', 8), parseInt('0664', 8));
-      done();
-    }, done);
+    fs.promises
+      .chmod('file.txt', parseInt('0664', 8))
+      .then(function () {
+        const stats = fs.statSync('file.txt');
+        assert.equal(stats.mode & parseInt('0777', 8), parseInt('0664', 8));
+        done();
+      })
+      .catch(done);
   });
 
   it('fails if file does not exist', function (done) {
@@ -61,7 +63,7 @@ describe('fs.chmod(path, mode, callback)', function () {
         assert.instanceOf(err, Error);
         assert.equal(err.code, 'ENOENT');
         done();
-      }
+      },
     );
   });
 });
@@ -117,7 +119,8 @@ describe('fs.fchmod(fd, mode, callback)', function () {
         const stats = fs.statSync('file.txt');
         assert.equal(stats.mode & parseInt('0777', 8), parseInt('0644', 8));
         done();
-      }, done);
+      })
+      .catch(done);
   });
 });
 
