@@ -1,11 +1,9 @@
-'use strict';
-
-const helper = require('../helper.js');
 const fs = require('fs');
+const {afterEach, beforeEach, describe, it} = require('mocha');
 const mock = require('../../lib/index.js');
+const helper = require('../helper.js');
 
 const assert = helper.assert;
-const inVersion = helper.inVersion;
 
 describe('fs.link(srcpath, dstpath, callback)', function () {
   beforeEach(function () {
@@ -49,13 +47,16 @@ describe('fs.link(srcpath, dstpath, callback)', function () {
   it('promise creates a link to a file', function (done) {
     assert.equal(fs.statSync('file.txt').nlink, 1);
 
-    fs.promises.link('file.txt', 'link.txt').then(function () {
-      assert.isTrue(fs.statSync('link.txt').isFile());
-      assert.equal(fs.statSync('link.txt').nlink, 2);
-      assert.equal(fs.statSync('file.txt').nlink, 2);
-      assert.equal(String(fs.readFileSync('link.txt')), 'content');
-      done();
-    }, done);
+    fs.promises
+      .link('file.txt', 'link.txt')
+      .then(function () {
+        assert.isTrue(fs.statSync('link.txt').isFile());
+        assert.equal(fs.statSync('link.txt').nlink, 2);
+        assert.equal(fs.statSync('file.txt').nlink, 2);
+        assert.equal(String(fs.readFileSync('link.txt')), 'content');
+        done();
+      })
+      .catch(done);
   });
 
   it('works if original is renamed', function (done) {
@@ -71,12 +72,15 @@ describe('fs.link(srcpath, dstpath, callback)', function () {
   });
 
   it('promise works if original is renamed', function (done) {
-    fs.promises.link('file.txt', 'link.txt').then(function () {
-      fs.renameSync('file.txt', 'renamed.txt');
-      assert.isTrue(fs.statSync('link.txt').isFile());
-      assert.equal(String(fs.readFileSync('link.txt')), 'content');
-      done();
-    }, done);
+    fs.promises
+      .link('file.txt', 'link.txt')
+      .then(function () {
+        fs.renameSync('file.txt', 'renamed.txt');
+        assert.isTrue(fs.statSync('link.txt').isFile());
+        assert.equal(String(fs.readFileSync('link.txt')), 'content');
+        done();
+      })
+      .catch(done);
   });
 
   it('works if original is removed', function (done) {
@@ -99,15 +103,18 @@ describe('fs.link(srcpath, dstpath, callback)', function () {
   it('promise works if original is removed', function (done) {
     assert.equal(fs.statSync('file.txt').nlink, 1);
 
-    fs.promises.link('file.txt', 'link.txt').then(function () {
-      assert.equal(fs.statSync('link.txt').nlink, 2);
-      assert.equal(fs.statSync('file.txt').nlink, 2);
-      fs.unlinkSync('file.txt');
-      assert.isTrue(fs.statSync('link.txt').isFile());
-      assert.equal(fs.statSync('link.txt').nlink, 1);
-      assert.equal(String(fs.readFileSync('link.txt')), 'content');
-      done();
-    }, done);
+    fs.promises
+      .link('file.txt', 'link.txt')
+      .then(function () {
+        assert.equal(fs.statSync('link.txt').nlink, 2);
+        assert.equal(fs.statSync('file.txt').nlink, 2);
+        fs.unlinkSync('file.txt');
+        assert.isTrue(fs.statSync('link.txt').isFile());
+        assert.equal(fs.statSync('link.txt').nlink, 1);
+        assert.equal(String(fs.readFileSync('link.txt')), 'content');
+        done();
+      })
+      .catch(done);
   });
 
   it('fails if original is a directory', function (done) {
@@ -127,7 +134,7 @@ describe('fs.link(srcpath, dstpath, callback)', function () {
         assert.instanceOf(err, Error);
         assert.equal(err.code, 'EPERM');
         done();
-      }
+      },
     );
   });
 });
@@ -189,7 +196,7 @@ describe('fs.symlink(srcpath, dstpath, [type], callback)', function () {
 
   // https://github.com/nodejs/node/issues/34514
   if (process.platform === 'win32') {
-    inVersion('>=15.0.0').it('supports Buffer input', function (done) {
+    it('supports Buffer input', function (done) {
       fs.symlink(
         Buffer.from('../file.txt'),
         Buffer.from('dir/link.txt'),
@@ -200,7 +207,7 @@ describe('fs.symlink(srcpath, dstpath, [type], callback)', function () {
           assert.isTrue(fs.statSync('dir/link.txt').isFile());
           assert.equal(String(fs.readFileSync('dir/link.txt')), 'content');
           done();
-        }
+        },
       );
     });
   } else {
@@ -215,17 +222,20 @@ describe('fs.symlink(srcpath, dstpath, [type], callback)', function () {
           assert.isTrue(fs.statSync('dir/link.txt').isFile());
           assert.equal(String(fs.readFileSync('dir/link.txt')), 'content');
           done();
-        }
+        },
       );
     });
   }
 
   it('promise creates a symbolic link to a file', function (done) {
-    fs.promises.symlink('../file.txt', 'dir/link.txt').then(function () {
-      assert.isTrue(fs.statSync('dir/link.txt').isFile());
-      assert.equal(String(fs.readFileSync('dir/link.txt')), 'content');
-      done();
-    }, done);
+    fs.promises
+      .symlink('../file.txt', 'dir/link.txt')
+      .then(function () {
+        assert.isTrue(fs.statSync('dir/link.txt').isFile());
+        assert.equal(String(fs.readFileSync('dir/link.txt')), 'content');
+        done();
+      })
+      .catch(done);
   });
 
   it('breaks if original is renamed', function (done) {
@@ -241,12 +251,15 @@ describe('fs.symlink(srcpath, dstpath, [type], callback)', function () {
   });
 
   it('promise breaks if original is renamed', function (done) {
-    fs.promises.symlink('file.txt', 'link.txt').then(function () {
-      assert.isTrue(fs.existsSync('link.txt'));
-      fs.renameSync('file.txt', 'renamed.txt');
-      assert.isFalse(fs.existsSync('link.txt'));
-      done();
-    }, done);
+    fs.promises
+      .symlink('file.txt', 'link.txt')
+      .then(function () {
+        assert.isTrue(fs.existsSync('link.txt'));
+        fs.renameSync('file.txt', 'renamed.txt');
+        assert.isFalse(fs.existsSync('link.txt'));
+        done();
+      })
+      .catch(done);
   });
 
   it('works if original is a directory', function (done) {
@@ -260,10 +273,13 @@ describe('fs.symlink(srcpath, dstpath, [type], callback)', function () {
   });
 
   it('promise works if original is a directory', function (done) {
-    fs.promises.symlink('dir', 'link').then(function () {
-      assert.isTrue(fs.statSync('link').isDirectory());
-      done();
-    }, done);
+    fs.promises
+      .symlink('dir', 'link')
+      .then(function () {
+        assert.isTrue(fs.statSync('link').isDirectory());
+        done();
+      })
+      .catch(done);
   });
 });
 
@@ -293,4 +309,10 @@ describe('fs.symlinkSync(srcpath, dstpath, [type])', function () {
     fs.symlinkSync('dir', 'link');
     assert.isTrue(fs.statSync('link').isDirectory());
   });
+
+  it('exists works if symlink is relative', function () {
+    fs.renameSync('file.txt', 'dir/file.txt');
+    fs.symlinkSync('file.txt', 'dir/link.txt');
+    assert.isTrue(fs.existsSync('dir/link.txt'));
+  });
 });
