@@ -1,8 +1,7 @@
-'use strict';
-
-const helper = require('../helper.js');
 const fs = require('fs');
+const {afterEach, beforeEach, describe, it} = require('mocha');
 const mock = require('../../lib/index.js');
+const helper = require('../helper.js');
 
 const assert = helper.assert;
 
@@ -44,11 +43,14 @@ describe('fs.mkdir(path, [mode], callback)', function () {
   });
 
   it('promise creates a new directory', function (done) {
-    fs.promises.mkdir('parent/dir').then(function () {
-      const stats = fs.statSync('parent/dir');
-      assert.isTrue(stats.isDirectory());
-      done();
-    }, done);
+    fs.promises
+      .mkdir('parent/dir')
+      .then(function () {
+        const stats = fs.statSync('parent/dir');
+        assert.isTrue(stats.isDirectory());
+        done();
+      })
+      .catch(done);
   });
 
   it('creates a new directory recursively', function (done) {
@@ -77,7 +79,8 @@ describe('fs.mkdir(path, [mode], callback)', function () {
         stats = fs.statSync('parent/foo');
         assert.isTrue(stats.isDirectory());
         done();
-      }, done);
+      })
+      .catch(done);
   });
 
   it('accepts dir mode', function (done) {
@@ -93,12 +96,15 @@ describe('fs.mkdir(path, [mode], callback)', function () {
   });
 
   it('promise accepts dir mode', function (done) {
-    fs.promises.mkdir('parent/dir', parseInt('0755', 8)).then(function () {
-      const stats = fs.statSync('parent/dir');
-      assert.isTrue(stats.isDirectory());
-      assert.equal(stats.mode & parseInt('0777', 8), parseInt('0755', 8));
-      done();
-    }, done);
+    fs.promises
+      .mkdir('parent/dir', parseInt('0755', 8))
+      .then(function () {
+        const stats = fs.statSync('parent/dir');
+        assert.isTrue(stats.isDirectory());
+        assert.equal(stats.mode & parseInt('0777', 8), parseInt('0755', 8));
+        done();
+      })
+      .catch(done);
   });
 
   it('accepts dir mode recursively', function (done) {
@@ -121,7 +127,7 @@ describe('fs.mkdir(path, [mode], callback)', function () {
         assert.isTrue(stats.isDirectory());
         assert.equal(stats.mode & parseInt('0777', 8), parseInt('0755', 8));
         done();
-      }
+      },
     );
   });
 
@@ -141,7 +147,8 @@ describe('fs.mkdir(path, [mode], callback)', function () {
         assert.isTrue(stats.isDirectory());
         assert.equal(stats.mode & parseInt('0777', 8), parseInt('0755', 8));
         done();
-      }, done);
+      })
+      .catch(done);
   });
 
   it('fails if parent does not exist', function (done) {
@@ -161,7 +168,7 @@ describe('fs.mkdir(path, [mode], callback)', function () {
         assert.instanceOf(err, Error);
         assert.equal(err.code, 'ENOENT');
         done();
-      }
+      },
     );
   });
 
@@ -180,7 +187,7 @@ describe('fs.mkdir(path, [mode], callback)', function () {
       function (err) {
         assert.instanceOf(err, Error);
         done();
-      }
+      },
     );
   });
 
@@ -191,7 +198,7 @@ describe('fs.mkdir(path, [mode], callback)', function () {
       function (err) {
         assert.instanceOf(err, Error);
         done();
-      }
+      },
     );
   });
 
@@ -208,7 +215,7 @@ describe('fs.mkdir(path, [mode], callback)', function () {
         function (err) {
           assert.instanceOf(err, Error);
           done();
-        }
+        },
       );
   });
 
@@ -229,7 +236,7 @@ describe('fs.mkdir(path, [mode], callback)', function () {
         assert.instanceOf(err, Error);
         assert.equal(err.code, 'EEXIST');
         done();
-      }
+      },
     );
   });
 
@@ -250,7 +257,7 @@ describe('fs.mkdir(path, [mode], callback)', function () {
         assert.instanceOf(err, Error);
         assert.equal(err.code, 'EEXIST');
         done();
-      }
+      },
     );
   });
 
@@ -271,7 +278,7 @@ describe('fs.mkdir(path, [mode], callback)', function () {
         assert.instanceOf(err, Error);
         assert.equal(err.code, 'EEXIST');
         done();
-      }
+      },
     );
   });
 
@@ -304,7 +311,7 @@ describe('fs.mkdir(path, [mode], callback)', function () {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EACCES');
           done();
-        }
+        },
       );
     });
   }
