@@ -1,26 +1,25 @@
-'use strict';
-
-const helper = require('../helper');
 const fs = require('fs');
-const mock = require('../../lib/index');
+const {afterEach, beforeEach, describe, it} = require('mocha');
+const mock = require('../../lib/index.js');
+const helper = require('../helper.js');
 
 const assert = helper.assert;
 
-describe('fs.read(fd, buffer, offset, length, position, callback)', function() {
-  beforeEach(function() {
+describe('fs.read(fd, buffer, offset, length, position, callback)', function () {
+  beforeEach(function () {
     mock({
-      'path/to/file.txt': 'file content'
+      'path/to/file.txt': 'file content',
     });
   });
   afterEach(mock.restore);
 
-  it('allows file contents to be read', function(done) {
-    fs.open('path/to/file.txt', 'r', function(err, fd) {
+  it('allows file contents to be read', function (done) {
+    fs.open('path/to/file.txt', 'r', function (err, fd) {
       if (err) {
         return done(err);
       }
       const buffer = Buffer.alloc(12);
-      fs.read(fd, buffer, 0, 12, 0, function(err2, bytesRead, buf) {
+      fs.read(fd, buffer, 0, 12, 0, function (err2, bytesRead, buf) {
         if (err2) {
           return done(err2);
         }
@@ -32,28 +31,29 @@ describe('fs.read(fd, buffer, offset, length, position, callback)', function() {
     });
   });
 
-  it('promise allows file contents to be read', function(done) {
+  it('promise allows file contents to be read', function (done) {
     const buffer = Buffer.alloc(12);
     fs.promises
       .open('path/to/file.txt', 'r')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.read(buffer, 0, 12, 0);
       })
-      .then(function(result) {
+      .then(function (result) {
         assert.equal(result.bytesRead, 12);
         assert.equal(result.buffer, buffer);
         assert.equal(String(buffer), 'file content');
         done();
-      }, done);
+      })
+      .catch(done);
   });
 
-  it('allows file contents to be read w/ offset', function(done) {
-    fs.open('path/to/file.txt', 'r', function(err, fd) {
+  it('allows file contents to be read w/ offset', function (done) {
+    fs.open('path/to/file.txt', 'r', function (err, fd) {
       if (err) {
         return done(err);
       }
       const buffer = Buffer.alloc(12);
-      fs.read(fd, buffer, 5, 7, 0, function(err2, bytesRead, buf) {
+      fs.read(fd, buffer, 5, 7, 0, function (err2, bytesRead, buf) {
         if (err2) {
           return done(err2);
         }
@@ -65,28 +65,29 @@ describe('fs.read(fd, buffer, offset, length, position, callback)', function() {
     });
   });
 
-  it('promise allows file contents to be read w/ offset', function(done) {
+  it('promise allows file contents to be read w/ offset', function (done) {
     const buffer = Buffer.alloc(12);
     fs.promises
       .open('path/to/file.txt', 'r')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.read(buffer, 5, 7, 0);
       })
-      .then(function(result) {
+      .then(function (result) {
         assert.equal(result.bytesRead, 7);
         assert.equal(result.buffer, buffer);
         assert.equal(String(buffer.slice(5)), 'file co');
         done();
-      }, done);
+      })
+      .catch(done);
   });
 
-  it('allows file contents to be read w/ length', function(done) {
-    fs.open('path/to/file.txt', 'r', function(err, fd) {
+  it('allows file contents to be read w/ length', function (done) {
+    fs.open('path/to/file.txt', 'r', function (err, fd) {
       if (err) {
         return done(err);
       }
       const buffer = Buffer.alloc(12);
-      fs.read(fd, buffer, 0, 4, 0, function(err2, bytesRead, buf) {
+      fs.read(fd, buffer, 0, 4, 0, function (err2, bytesRead, buf) {
         if (err2) {
           return done(err2);
         }
@@ -98,28 +99,29 @@ describe('fs.read(fd, buffer, offset, length, position, callback)', function() {
     });
   });
 
-  it('promise allows file contents to be read w/ length', function(done) {
+  it('promise allows file contents to be read w/ length', function (done) {
     const buffer = Buffer.alloc(12);
     fs.promises
       .open('path/to/file.txt', 'r')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.read(buffer, 0, 4, 0);
       })
-      .then(function(result) {
+      .then(function (result) {
         assert.equal(result.bytesRead, 4);
         assert.equal(result.buffer, buffer);
         assert.equal(String(buffer.slice(0, 4)), 'file');
         done();
-      }, done);
+      })
+      .catch(done);
   });
 
-  it('allows file contents to be read w/ offset & length', function(done) {
-    fs.open('path/to/file.txt', 'r', function(err, fd) {
+  it('allows file contents to be read w/ offset & length', function (done) {
+    fs.open('path/to/file.txt', 'r', function (err, fd) {
       if (err) {
         return done(err);
       }
       const buffer = Buffer.alloc(12);
-      fs.read(fd, buffer, 2, 4, 0, function(err2, bytesRead, buf) {
+      fs.read(fd, buffer, 2, 4, 0, function (err2, bytesRead, buf) {
         if (err2) {
           return done(err2);
         }
@@ -131,28 +133,29 @@ describe('fs.read(fd, buffer, offset, length, position, callback)', function() {
     });
   });
 
-  it('promise allows file contents to be read w/ offset & length', function(done) {
+  it('promise allows file contents to be read w/ offset & length', function (done) {
     const buffer = Buffer.alloc(12);
     fs.promises
       .open('path/to/file.txt', 'r')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.read(buffer, 2, 4, 0);
       })
-      .then(function(result) {
+      .then(function (result) {
         assert.equal(result.bytesRead, 4);
         assert.equal(result.buffer, buffer);
         assert.equal(String(buffer.slice(2, 6)), 'file');
         done();
-      }, done);
+      })
+      .catch(done);
   });
 
-  it('allows file contents to be read w/ position', function(done) {
-    fs.open('path/to/file.txt', 'r', function(err, fd) {
+  it('allows file contents to be read w/ position', function (done) {
+    fs.open('path/to/file.txt', 'r', function (err, fd) {
       if (err) {
         return done(err);
       }
       const buffer = Buffer.alloc(7);
-      fs.read(fd, buffer, 0, 7, 5, function(err2, bytesRead, buf) {
+      fs.read(fd, buffer, 0, 7, 5, function (err2, bytesRead, buf) {
         if (err2) {
           return done(err2);
         }
@@ -164,28 +167,29 @@ describe('fs.read(fd, buffer, offset, length, position, callback)', function() {
     });
   });
 
-  it('promise allows file contents to be read w/ position', function(done) {
+  it('promise allows file contents to be read w/ position', function (done) {
     const buffer = Buffer.alloc(7);
     fs.promises
       .open('path/to/file.txt', 'r')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.read(buffer, 0, 7, 5);
       })
-      .then(function(result) {
+      .then(function (result) {
         assert.equal(result.bytesRead, 7);
         assert.equal(result.buffer, buffer);
         assert.equal(String(buffer), 'content');
         done();
-      }, done);
+      })
+      .catch(done);
   });
 
-  it('allows read w/ offset, length, & position', function(done) {
-    fs.open('path/to/file.txt', 'r', function(err, fd) {
+  it('allows read w/ offset, length, & position', function (done) {
+    fs.open('path/to/file.txt', 'r', function (err, fd) {
       if (err) {
         return done(err);
       }
       const buffer = Buffer.alloc(12);
-      fs.read(fd, buffer, 2, 7, 5, function(err2, bytesRead, buf) {
+      fs.read(fd, buffer, 2, 7, 5, function (err2, bytesRead, buf) {
         if (err2) {
           return done(err2);
         }
@@ -197,25 +201,26 @@ describe('fs.read(fd, buffer, offset, length, position, callback)', function() {
     });
   });
 
-  it('promise allows read w/ offset, length, & position', function(done) {
+  it('promise allows read w/ offset, length, & position', function (done) {
     const buffer = Buffer.alloc(12);
     fs.promises
       .open('path/to/file.txt', 'r')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.read(buffer, 2, 7, 5);
       })
-      .then(function(result) {
+      .then(function (result) {
         assert.equal(result.bytesRead, 7);
         assert.equal(result.buffer, buffer);
         assert.equal(String(buffer.slice(2, 9)), 'content');
         done();
-      }, done);
+      })
+      .catch(done);
   });
 
-  it('fails for closed file descriptor', function(done) {
+  it('fails for closed file descriptor', function (done) {
     const fd = fs.openSync('path/to/file.txt', 'r');
     fs.closeSync(fd);
-    fs.read(fd, Buffer.alloc(12), 0, 12, 0, function(err, bytesRead, buf) {
+    fs.read(fd, Buffer.alloc(12), 0, 12, 0, function (err, bytesRead, buf) {
       assert.instanceOf(err, Error);
       assert.equal(err.code, 'EBADF');
       assert.equal(0, bytesRead);
@@ -223,63 +228,63 @@ describe('fs.read(fd, buffer, offset, length, position, callback)', function() {
     });
   });
 
-  it('promise fails for closed file descriptor', function(done) {
+  it('promise fails for closed file descriptor', function (done) {
     fs.promises
       .open('path/to/file.txt', 'r')
-      .then(function(fd) {
-        return fd.close().then(function() {
+      .then(function (fd) {
+        return fd.close().then(function () {
           return fd.read(Buffer.alloc(12), 0, 12, 0);
         });
       })
       .then(
-        function() {
+        function () {
           done(new Error('should not succeed.'));
         },
-        function(err) {
+        function (err) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EBADF');
           done();
-        }
+        },
       );
   });
 
-  it('fails if not open for reading', function(done) {
+  it('fails if not open for reading', function (done) {
     const fd = fs.openSync('path/to/file.txt', 'w');
-    fs.read(fd, Buffer.alloc(12), 0, 12, 0, function(err, bytesRead, buf) {
+    fs.read(fd, Buffer.alloc(12), 0, 12, 0, function (err, bytesRead, buf) {
       assert.instanceOf(err, Error);
       assert.equal(0, bytesRead);
       done();
     });
   });
 
-  it('promise fails if not open for reading', function(done) {
+  it('promise fails if not open for reading', function (done) {
     fs.promises
       .open('path/to/file.txt', 'w')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.read(Buffer.alloc(12), 0, 12, 0);
       })
       .then(
-        function() {
+        function () {
           done(new Error('should not succeed.'));
         },
-        function(err) {
+        function (err) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EBADF');
           done();
-        }
+        },
       );
   });
 });
 
-describe('fs.readSync(fd, buffer, offset, length, position)', function() {
-  beforeEach(function() {
+describe('fs.readSync(fd, buffer, offset, length, position)', function () {
+  beforeEach(function () {
     mock({
-      'path/to/file.txt': 'file content'
+      'path/to/file.txt': 'file content',
     });
   });
   afterEach(mock.restore);
 
-  it('allows a file to be read synchronously', function() {
+  it('allows a file to be read synchronously', function () {
     const fd = fs.openSync('path/to/file.txt', 'r');
     const buffer = Buffer.alloc(12);
     const read = fs.readSync(fd, buffer, 0, 12, 0);
@@ -287,7 +292,7 @@ describe('fs.readSync(fd, buffer, offset, length, position)', function() {
     assert.equal(String(buffer), 'file content');
   });
 
-  it('allows a file to be read in two parts', function() {
+  it('allows a file to be read in two parts', function () {
     const fd = fs.openSync('path/to/file.txt', 'r');
     const first = Buffer.alloc(4);
     fs.readSync(fd, first, 0, 4, 0);
@@ -298,7 +303,7 @@ describe('fs.readSync(fd, buffer, offset, length, position)', function() {
     assert.equal(String(second), 'content');
   });
 
-  it('treats null position as current position', function() {
+  it('treats null position as current position', function () {
     const fd = fs.openSync('path/to/file.txt', 'r');
     const first = Buffer.alloc(4);
     fs.readSync(fd, first, 0, 4, null);
