@@ -1,8 +1,7 @@
-'use strict';
-
-const helper = require('../helper.js');
 const fs = require('fs');
+const {afterEach, beforeEach, describe, it} = require('mocha');
 const mock = require('../../lib/index.js');
+const helper = require('../helper.js');
 
 const assert = helper.assert;
 
@@ -29,11 +28,14 @@ describe('fs.readFile(filename, [options], callback)', function () {
   });
 
   it('promise allows a file to be read asynchronously', function (done) {
-    fs.promises.readFile('path/to/file.txt').then(function (data) {
-      assert.isTrue(Buffer.isBuffer(data));
-      assert.equal(String(data), 'file content');
-      done();
-    }, done);
+    fs.promises
+      .readFile('path/to/file.txt')
+      .then(function (data) {
+        assert.isTrue(Buffer.isBuffer(data));
+        assert.equal(String(data), 'file content');
+        done();
+      })
+      .catch(done);
   });
 
   it('fails for directory', function (done) {
@@ -53,7 +55,7 @@ describe('fs.readFile(filename, [options], callback)', function () {
         assert.instanceOf(err, Error);
         assert.equal(err.code, 'EISDIR');
         done();
-      }
+      },
     );
   });
 
@@ -76,7 +78,7 @@ describe('fs.readFile(filename, [options], callback)', function () {
         // windows has different errno for ENOENT
         assert.equal(err.code, 'ENOENT');
         done();
-      }
+      },
     );
   });
 });
@@ -92,6 +94,11 @@ describe('fs.readFileSync(filename, [options])', function () {
   });
   afterEach(mock.restore);
 
+  it('works with utf-8', function () {
+    const content = fs.readFileSync('path/to/file.txt', 'utf-8').toString();
+    assert.equal(content, 'file content');
+  });
+
   it('allows a file to be read synchronously', function () {
     const data = fs.readFileSync('path/to/file.txt');
     assert.isTrue(Buffer.isBuffer(data));
