@@ -1,9 +1,8 @@
-'use strict';
-
-const helper = require('../helper.js');
 const fs = require('fs');
-const mock = require('../../lib/index.js');
 const path = require('path');
+const {afterEach, beforeEach, describe, it} = require('mocha');
+const mock = require('../../lib/index.js');
+const helper = require('../helper.js');
 
 const assert = helper.assert;
 
@@ -51,11 +50,14 @@ describe('fs.readdir(path, callback)', function () {
   });
 
   it('promise lists directory contents', function (done) {
-    fs.promises.readdir(path.join('path', 'to')).then(function (items) {
-      assert.isArray(items);
-      assert.deepEqual(items, ['file.txt']);
-      done();
-    }, done);
+    fs.promises
+      .readdir(path.join('path', 'to'))
+      .then(function (items) {
+        assert.isArray(items);
+        assert.deepEqual(items, ['file.txt']);
+        done();
+      })
+      .catch(done);
   });
 
   it('lists nested directory contents', function (done) {
@@ -74,7 +76,8 @@ describe('fs.readdir(path, callback)', function () {
         assert.isArray(items);
         assert.deepEqual(items, ['empty', 'one.txt', 'two.txt']);
         done();
-      }, done);
+      })
+      .catch(done);
   });
 
   it('calls with an error for bogus path', function (done) {
@@ -93,7 +96,7 @@ describe('fs.readdir(path, callback)', function () {
       function (err) {
         assert.instanceOf(err, Error);
         done();
-      }
+      },
     );
   });
 
@@ -115,7 +118,7 @@ describe('fs.readdir(path, callback)', function () {
         assert.instanceOf(err, Error);
         assert.equal(err.code, 'EACCES');
         done();
-      }
+      },
     );
   });
 
@@ -128,13 +131,13 @@ describe('fs.readdir(path, callback)', function () {
         assert.isArray(items);
         assert.deepEqual(
           items.map((i) => i.name),
-          ['empty', 'one.txt', 'two.txt']
+          ['empty', 'one.txt', 'two.txt'],
         );
         assert.ok(items[0].isDirectory());
         assert.ok(items[1].isFile());
         assert.ok(items[2].isFile());
         done();
-      }
+      },
     );
   });
 
@@ -145,13 +148,14 @@ describe('fs.readdir(path, callback)', function () {
         assert.isArray(items);
         assert.deepEqual(
           items.map((i) => i.name),
-          ['empty', 'one.txt', 'two.txt']
+          ['empty', 'one.txt', 'two.txt'],
         );
         assert.ok(items[0].isDirectory());
         assert.ok(items[1].isFile());
         assert.ok(items[2].isFile());
         done();
-      }, done);
+      })
+      .catch(done);
   });
 
   it('should support "withFileTypes" option with "encoding" option', function (done) {
@@ -172,7 +176,7 @@ describe('fs.readdir(path, callback)', function () {
         assert.ok(items[1].isFile());
         assert.ok(items[2].isFile());
         done();
-      }
+      },
     );
   });
 
