@@ -1,8 +1,7 @@
-'use strict';
-
-const helper = require('../helper.js');
 const fs = require('fs');
+const {afterEach, beforeEach, describe, it} = require('mocha');
 const mock = require('../../lib/index.js');
+const helper = require('../helper.js');
 
 const assert = helper.assert;
 
@@ -36,10 +35,13 @@ describe('fs.readlink(path, callback)', function () {
   });
 
   it('promise reads a symbolic link', function (done) {
-    fs.promises.readlink('link').then(function (srcPath) {
-      assert.equal(srcPath, './file.txt');
-      done();
-    }, done);
+    fs.promises
+      .readlink('link')
+      .then(function (srcPath) {
+        assert.equal(srcPath, './file.txt');
+        done();
+      })
+      .catch(done);
   });
 
   it('fails for regular files', function (done) {
@@ -57,7 +59,7 @@ describe('fs.readlink(path, callback)', function () {
       function (err) {
         assert.instanceOf(err, Error);
         done();
-      }
+      },
     );
   });
 });
