@@ -1,9 +1,8 @@
-'use strict';
-
-const helper = require('../helper.js');
 const fs = require('fs');
-const mock = require('../../lib/index.js');
+const {afterEach, beforeEach, describe, it, xit} = require('mocha');
 const semver = require('semver');
+const mock = require('../../lib/index.js');
+const helper = require('../helper.js');
 
 const assert = helper.assert;
 
@@ -37,10 +36,13 @@ describe('fs.stat(path, options, callback)', function () {
   });
 
   xit('promise creates an instance of fs.Stats', function (done) {
-    fs.promises.stat('/path/to/file.txt').then(function (stats) {
-      assert.instanceOf(stats, fs.Stats);
-      done();
-    }, done);
+    fs.promises
+      .stat('/path/to/file.txt')
+      .then(function (stats) {
+        assert.instanceOf(stats, fs.Stats);
+        done();
+      })
+      .catch(done);
   });
 
   it('identifies files', function (done) {
@@ -91,17 +93,20 @@ describe('fs.stat(path, options, callback)', function () {
         assert.isFalse(stats.isDirectory());
         assert.equal(typeof stats.mtimeMs, 'bigint');
         done();
-      }
+      },
     );
   });
 
   it('promise identifies files', function (done) {
-    fs.promises.stat('/path/to/file.txt').then(function (stats) {
-      assert.isTrue(stats.isFile());
-      assert.isFalse(stats.isDirectory());
-      done();
-      assert.equal(stats.mtime.getTime(), 2);
-    }, done);
+    fs.promises
+      .stat('/path/to/file.txt')
+      .then(function (stats) {
+        assert.isTrue(stats.isFile());
+        assert.isFalse(stats.isDirectory());
+        done();
+        assert.equal(stats.mtime.getTime(), 2);
+      })
+      .catch(done);
   });
 
   it('promise identifies files', function (done) {
@@ -112,7 +117,8 @@ describe('fs.stat(path, options, callback)', function () {
         assert.isFalse(stats.isDirectory());
         done();
         assert.equal(typeof stats.mtimeMs, 'bigint');
-      }, done);
+      })
+      .catch(done);
   });
 
   it('identifies directories', function (done) {
@@ -140,21 +146,27 @@ describe('fs.stat(path, options, callback)', function () {
   });
 
   it('promise identifies directories', function (done) {
-    fs.promises.stat('/empty').then(function (stats) {
-      assert.isTrue(stats.isDirectory());
-      assert.isFalse(stats.isFile());
-      assert.equal(stats.size, 1);
-      done();
-    }, done);
+    fs.promises
+      .stat('/empty')
+      .then(function (stats) {
+        assert.isTrue(stats.isDirectory());
+        assert.isFalse(stats.isFile());
+        assert.equal(stats.size, 1);
+        done();
+      })
+      .catch(done);
   });
 
   it('promise identifies directories with bigint', function (done) {
-    fs.promises.stat('/empty', {bigint: true}).then(function (stats) {
-      assert.isTrue(stats.isDirectory());
-      assert.isFalse(stats.isFile());
-      assert.equal(typeof stats.size, 'bigint');
-      done();
-    }, done);
+    fs.promises
+      .stat('/empty', {bigint: true})
+      .then(function (stats) {
+        assert.isTrue(stats.isDirectory());
+        assert.isFalse(stats.isFile());
+        assert.equal(typeof stats.size, 'bigint');
+        done();
+      })
+      .catch(done);
   });
 
   it('provides file stats', function (done) {
@@ -190,16 +202,19 @@ describe('fs.stat(path, options, callback)', function () {
   });
 
   it('promise provides file stats', function (done) {
-    fs.promises.stat('/path/to/file.txt').then(function (stats) {
-      assert.equal(stats.ctime.getTime(), 1);
-      assert.equal(stats.mtime.getTime(), 2);
-      assert.equal(stats.atime.getTime(), 3);
-      assert.equal(stats.uid, 42);
-      assert.equal(stats.gid, 43);
-      assert.equal(stats.nlink, 1);
-      assert.isNumber(stats.rdev);
-      done();
-    }, done);
+    fs.promises
+      .stat('/path/to/file.txt')
+      .then(function (stats) {
+        assert.equal(stats.ctime.getTime(), 1);
+        assert.equal(stats.mtime.getTime(), 2);
+        assert.equal(stats.atime.getTime(), 3);
+        assert.equal(stats.uid, 42);
+        assert.equal(stats.gid, 43);
+        assert.equal(stats.nlink, 1);
+        assert.isNumber(stats.rdev);
+        done();
+      })
+      .catch(done);
   });
 
   it('promise provides file stats with bigint', function (done) {
@@ -214,7 +229,8 @@ describe('fs.stat(path, options, callback)', function () {
         assert.equal(typeof stats.nlink, 'bigint');
         assert.equal(typeof stats.rdev, 'bigint');
         done();
-      }, done);
+      })
+      .catch(done);
   });
 
   if (
@@ -235,11 +251,14 @@ describe('fs.stat(path, options, callback)', function () {
     });
 
     it('promise includes blocks and blksize in stats', function (done) {
-      fs.promises.stat('/path/to/file.txt').then(function (stats) {
-        assert.isNumber(stats.blocks);
-        assert.isNumber(stats.blksize);
-        done();
-      }, done);
+      fs.promises
+        .stat('/path/to/file.txt')
+        .then(function (stats) {
+          assert.isNumber(stats.blocks);
+          assert.isNumber(stats.blksize);
+          done();
+        })
+        .catch(done);
     });
   }
 
@@ -292,45 +311,51 @@ describe('fs.stat(path, options, callback)', function () {
   });
 
   it('promise provides directory stats', function (done) {
-    fs.promises.stat('/path').then(function (stats) {
-      assert.instanceOf(stats.ctime, Date);
-      assert.instanceOf(stats.mtime, Date);
-      assert.instanceOf(stats.atime, Date);
-      if (process.getuid) {
-        assert.isNumber(stats.uid);
-      } else {
-        assert.strictEqual(stats.uid, 0);
-      }
-      if (process.getgid) {
-        assert.isNumber(stats.gid);
-      } else {
-        assert.strictEqual(stats.gid, 0);
-      }
-      assert.equal(stats.nlink, 3);
-      assert.isNumber(stats.rdev);
-      done();
-    }, done);
+    fs.promises
+      .stat('/path')
+      .then(function (stats) {
+        assert.instanceOf(stats.ctime, Date);
+        assert.instanceOf(stats.mtime, Date);
+        assert.instanceOf(stats.atime, Date);
+        if (process.getuid) {
+          assert.isNumber(stats.uid);
+        } else {
+          assert.strictEqual(stats.uid, 0);
+        }
+        if (process.getgid) {
+          assert.isNumber(stats.gid);
+        } else {
+          assert.strictEqual(stats.gid, 0);
+        }
+        assert.equal(stats.nlink, 3);
+        assert.isNumber(stats.rdev);
+        done();
+      })
+      .catch(done);
   });
 
   it('promise provides directory stats with bigint', function (done) {
-    fs.promises.stat('/path', {bigint: true}).then(function (stats) {
-      assert.instanceOf(stats.ctime, Date);
-      assert.instanceOf(stats.mtime, Date);
-      assert.instanceOf(stats.atime, Date);
-      if (process.getuid) {
-        assert.equal(typeof stats.uid, 'bigint');
-      } else {
-        assert.strictEqual(stats.uid, 0n);
-      }
-      if (process.getgid) {
-        assert.equal(typeof stats.gid, 'bigint');
-      } else {
-        assert.strictEqual(stats.gid, 0n);
-      }
-      assert.equal(typeof stats.nlink, 'bigint');
-      assert.equal(typeof stats.rdev, 'bigint');
-      done();
-    }, done);
+    fs.promises
+      .stat('/path', {bigint: true})
+      .then(function (stats) {
+        assert.instanceOf(stats.ctime, Date);
+        assert.instanceOf(stats.mtime, Date);
+        assert.instanceOf(stats.atime, Date);
+        if (process.getuid) {
+          assert.equal(typeof stats.uid, 'bigint');
+        } else {
+          assert.strictEqual(stats.uid, 0n);
+        }
+        if (process.getgid) {
+          assert.equal(typeof stats.gid, 'bigint');
+        } else {
+          assert.strictEqual(stats.gid, 0n);
+        }
+        assert.equal(typeof stats.nlink, 'bigint');
+        assert.equal(typeof stats.rdev, 'bigint');
+        done();
+      })
+      .catch(done);
   });
 
   if (
@@ -351,11 +376,14 @@ describe('fs.stat(path, options, callback)', function () {
     });
 
     it('promise includes blocks and blksize in directory stats', function (done) {
-      fs.promises.stat('/path').then(function (stats) {
-        assert.isNumber(stats.blocks);
-        assert.isNumber(stats.blksize);
-        done();
-      }, done);
+      fs.promises
+        .stat('/path')
+        .then(function (stats) {
+          assert.isNumber(stats.blocks);
+          assert.isNumber(stats.blksize);
+          done();
+        })
+        .catch(done);
     });
   }
 });
@@ -403,7 +431,8 @@ describe('fs.fstat(fd, options, callback)', function () {
         assert.isTrue(stats.isFile());
         assert.equal(stats.size, 12);
         done();
-      }, done);
+      })
+      .catch(done);
   });
 
   it('promise accepts a file descriptor for a file (r) with bigint', function (done) {
@@ -416,7 +445,8 @@ describe('fs.fstat(fd, options, callback)', function () {
         assert.isTrue(stats.isFile());
         assert.equal(typeof stats.size, 'bigint');
         done();
-      }, done);
+      })
+      .catch(done);
   });
 
   it('accepts a file descriptor for a directory (r)', function (done) {
@@ -453,7 +483,8 @@ describe('fs.fstat(fd, options, callback)', function () {
         assert.isTrue(stats.isDirectory());
         assert.equal(stats.size, 1);
         done();
-      }, done);
+      })
+      .catch(done);
   });
 
   it('promise accepts a file descriptor for a directory (r) with bigint', function (done) {
@@ -466,7 +497,8 @@ describe('fs.fstat(fd, options, callback)', function () {
         assert.isTrue(stats.isDirectory());
         assert.equal(typeof stats.size, 'bigint');
         done();
-      }, done);
+      })
+      .catch(done);
   });
 
   it('fails for bad file descriptor', function (done) {
@@ -495,7 +527,7 @@ describe('fs.fstat(fd, options, callback)', function () {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EBADF');
           done();
-        }
+        },
       );
   });
 });
