@@ -1,8 +1,7 @@
-'use strict';
-
-const helper = require('../helper.js');
 const fs = require('fs');
+const {afterEach, beforeEach, describe, it} = require('mocha');
 const mock = require('../../lib/index.js');
+const helper = require('../helper.js');
 
 const assert = helper.assert;
 
@@ -40,10 +39,13 @@ describe('fs.unlink(path, callback)', function () {
   });
 
   it('promise deletes a file', function (done) {
-    fs.promises.unlink('file.txt').then(function () {
-      assert.isFalse(fs.existsSync('file.txt'));
-      done();
-    }, done);
+    fs.promises
+      .unlink('file.txt')
+      .then(function () {
+        assert.isFalse(fs.existsSync('file.txt'));
+        done();
+      })
+      .catch(done);
   });
 
   it('updates mtime of parent', function (done) {
@@ -61,12 +63,15 @@ describe('fs.unlink(path, callback)', function () {
 
   it('updates mtime of parent', function (done) {
     const oldTime = fs.statSync('dir2').mtime;
-    fs.promises.unlink('dir2/file').then(function () {
-      assert.isFalse(fs.existsSync('dir2/file'));
-      const newTime = fs.statSync('dir2').mtime;
-      assert.isTrue(newTime > oldTime);
-      done();
-    }, done);
+    fs.promises
+      .unlink('dir2/file')
+      .then(function () {
+        assert.isFalse(fs.existsSync('dir2/file'));
+        const newTime = fs.statSync('dir2').mtime;
+        assert.isTrue(newTime > oldTime);
+        done();
+      })
+      .catch(done);
   });
 
   it('fails for a directory', function (done) {
@@ -88,7 +93,7 @@ describe('fs.unlink(path, callback)', function () {
         assert.equal(err.code, 'EPERM');
         assert.isTrue(fs.existsSync('dir'));
         done();
-      }
+      },
     );
   });
 
@@ -110,15 +115,18 @@ describe('fs.unlink(path, callback)', function () {
 
   it('promise respects previously opened file descriptors', function (done) {
     const fd = fs.openSync('file.txt', 'r');
-    fs.promises.unlink('file.txt').then(function () {
-      assert.isFalse(fs.existsSync('file.txt'));
-      // but we can still use fd to read
-      const buffer = Buffer.alloc(7);
-      const read = fs.readSync(fd, buffer, 0, 7);
-      assert.equal(read, 7);
-      assert.equal(String(buffer), 'content');
-      done();
-    }, done);
+    fs.promises
+      .unlink('file.txt')
+      .then(function () {
+        assert.isFalse(fs.existsSync('file.txt'));
+        // but we can still use fd to read
+        const buffer = Buffer.alloc(7);
+        const read = fs.readSync(fd, buffer, 0, 7);
+        assert.equal(read, 7);
+        assert.equal(String(buffer), 'content');
+        done();
+      })
+      .catch(done);
   });
 });
 
