@@ -1,5 +1,4 @@
-'use strict';
-
+const {beforeEach, describe, it} = require('mocha');
 const Item = require('../../lib/item.js');
 const assert = require('../helper.js').assert;
 
@@ -139,11 +138,15 @@ describe('Item', function () {
   });
 
   if (process.getgid && process.getuid) {
-    const uid = process.getuid();
-    const gid = process.getgid();
+    const originalGetuid = process.getuid;
+    const originalGetgid = process.getgid;
+    const uid = originalGetuid();
+    const gid = originalGetgid();
 
     let item;
     beforeEach(function () {
+      process.getuid = originalGetuid;
+      process.getgid = originalGetgid;
       item = new Item();
     });
 
@@ -220,6 +223,14 @@ describe('Item', function () {
         item.setMode(parseInt('0777', 8));
         assert.isTrue(item.canRead());
       });
+
+      it('always returns true if process runs as root', function () {
+        process.getuid = () => 0;
+        item.setUid(42);
+        item.setGid(42);
+        item.setMode(parseInt('0000', 8));
+        assert.isTrue(item.canRead());
+      });
     });
 
     describe('#canWrite()', function () {
@@ -295,6 +306,14 @@ describe('Item', function () {
         item.setMode(parseInt('0777', 8));
         assert.isTrue(item.canWrite());
       });
+
+      it('always returns true if process runs as root', function () {
+        process.getuid = () => 0;
+        item.setUid(42);
+        item.setGid(42);
+        item.setMode(parseInt('0000', 8));
+        assert.isTrue(item.canWrite());
+      });
     });
 
     describe('#canExecute()', function () {
@@ -370,6 +389,14 @@ describe('Item', function () {
         item.setMode(parseInt('0777', 8));
         assert.isTrue(item.canExecute());
       });
+
+      it('always returns true if process runs as root', function () {
+        process.getuid = () => 0;
+        item.setUid(42);
+        item.setGid(42);
+        item.setMode(parseInt('0000', 8));
+        assert.isTrue(item.canExecute());
+      });
     });
   }
 });
